package com.ruoyi.generator.service;

import com.ruoyi.generator.domain.Template;

import java.util.List;

/**
 * 代码模版Service接口
 * 
 * @author ruoyi
 * @date 2023-11-24
 */
public interface ITemplateService 
{
    /**
     * 查询代码模版
     * 
     * @param templateId 代码模版主键
     * @return 代码模版
     */
    public Template selectTemplateByTemplateId(Long templateId);

    /**
     * 查询代码模版列表
     * 
     * @param template 代码模版
     * @return 代码模版集合
     */
    public List<Template> selectTemplateList(Template template);

    /**
     * 新增代码模版
     * 
     * @param template 代码模版
     * @return 结果
     */
    public int insertTemplate(Template template);

    /**
     * 修改代码模版
     * 
     * @param template 代码模版
     * @return 结果
     */
    public int updateTemplate(Template template);

    /**
     * 批量删除代码模版
     * 
     * @param templateIds 需要删除的代码模版主键集合
     * @return 结果
     */
    public int deleteTemplateByTemplateIds(Long[] templateIds);

    /**
     * 删除代码模版信息
     * 
     * @param templateId 代码模版主键
     * @return 结果
     */
    public int deleteTemplateByTemplateId(Long templateId);

    public int updateTemplateStatus(Template template);

    String selectActiveTemplate();

    List<Template> selectAllTemplates();
}
